

const styles = [];
function registerCss(module) {
    const cssContent = module.default;
    if (typeof cssContent === 'string') {
        const sheet = new CSSStyleSheet();
        sheet.replaceSync(cssContent);
        const fontFaces = Array.from(sheet.cssRules)
            .filter((rule) => rule instanceof CSSFontFaceRule)
            .map((r) => r.cssText);
        if (fontFaces.length > 0) {
            const fontFaceStyle = document.createElement('style');
            fontFaceStyle.setAttribute('type', 'text/css');
            fontFaceStyle.appendChild(document.createTextNode(fontFaces.join('\n')));
            document.head.insertBefore(fontFaceStyle, document.head.firstChild);
        }
        styles.push(cssContent);
    }
}
function getInjectElement(target) {
    const root = target.getRootNode();
    if (root instanceof ShadowRoot) {
        return root;
    }
    return document.head;
}
function injectCss(target) {
    const root = getInjectElement(target);
    if (root instanceof ShadowRoot && styles.length === 0) {
        console.error("@codingame/monaco-vscode-api was loaded inside a shadow dom, but it's unable to load the css into it because the bundler configuration wasn't applied properly: imported css files should export their content as default");
    }
    for (const style of styles) {
        const styleEl = document.createElement('style');
        styleEl.appendChild(document.createTextNode(style));
        root.appendChild(styleEl);
    }
}

export { injectCss, registerCss };
